@@ -16,6 +16,7 @@ extern const char program[];
 
 extern const char* cvm_account_name;
 extern const char* cvm_account_domain;
+extern const char* cvm_lookup_secret;
 
 extern char outbuffer[BUFSIZE];
 extern unsigned outbuflen;
@@ -27,6 +28,7 @@ extern int cvm_fact_str(int number, const char* data);
 extern int cvm_fact_uint(int number, unsigned long data);
 extern void cvm_fact_end(int code);
 
+extern void init_request(void);
 extern int handle_request(void);
 
 extern void log_startup(void);
@@ -40,7 +42,9 @@ extern int cvm_parse_domain(const char* seperators);
 extern const unsigned cvm_credential_count;
 extern const char* cvm_credentials[];
 extern int cvm_auth_init(void);
+extern int cvm_lookup(void);
 extern int cvm_authenticate(void);
+extern int cvm_results(void);
 extern void cvm_auth_stop(void);
 
 #endif
