@@ -58,7 +58,7 @@ run_compare_test() {
   if ! cmp $tmp/expected $tmp/actual >/dev/null 2>&1
   then
     echo "Test $name $@ failed:"
-	( cd $tmp; diff -u9999 expected actual | tail -n +3; echo; )
+	( cd $tmp; diff -U 9999 expected actual | tail -n +3; echo; )
 	let tests_failed=tests_failed+1
   fi
   rm -f $tmp/expected $tmp/actual
@@ -378,6 +378,48 @@ domain:           local.dom
 mailbox path:     @TMPDIR@/alias
 END_OF_TEST_RESULTS
 
+run_compare_test tests/qmail-lookup 'USER' 'local.dom' <<END_OF_TEST_RESULTS
+user name:        user
+user ID:          @UID@
+group ID:         @GID@
+real name:        (null)
+directory:        @TMPDIR@
+shell:            (null)
+group name:       (null)
+system user name: user
+system directory: @TMPDIR@
+domain:           local.dom
+mailbox path:     @TMPDIR@
+END_OF_TEST_RESULTS
+
+run_compare_test tests/qmail-lookup 'user-ADDR' 'local.dom' <<END_OF_TEST_RESULTS
+user name:        user
+user ID:          @UID@
+group ID:         @GID@
+real name:        (null)
+directory:        @TMPDIR@
+shell:            (null)
+group name:       (null)
+system user name: user
+system directory: @TMPDIR@
+domain:           local.dom
+mailbox path:     @TMPDIR@
+END_OF_TEST_RESULTS
+
+run_compare_test tests/qmail-lookup 'USER-ADDR' 'local.dom' <<END_OF_TEST_RESULTS
+user name:        user
+user ID:          @UID@
+group ID:         @GID@
+real name:        (null)
+directory:        @TMPDIR@
+shell:            (null)
+group name:       (null)
+system user name: user
+system directory: @TMPDIR@
+domain:           local.dom
+mailbox path:     @TMPDIR@
+END_OF_TEST_RESULTS
+
 
 ##### Test tests/vmlookup-upper-virt #####
 
